All of lore.kernel.org
 help / color / mirror / Atom feed
* [PATCH 1/63] usb/message: make usb_{control,bulk}_msg() use msecs
@ 2005-05-19  6:25 ` Nishanth Aravamudan
  0 siblings, 0 replies; 6+ messages in thread
From: Nishanth Aravamudan @ 2005-02-09  0:12 UTC (permalink / raw)
  To: gregkh, marcel, maxk, jt, perex, linux-dvb-maintainer, johnpol
  Cc: linux-usb-devel, bluez-devel, irda-users, alsa-devel, linux-dvb,
	sensors

Hi,

Sent to everyone so that build and compile tests will be possible. Only Greg
should need to pull this into a tree, though, to send upstream.

Thanks,
Nish

Description: Change the units of the timeout parameter in both usb_control_msg()
and usb_bulk_msg() from jiffies to milliseconds. This is the core patch upon
which the remaining ones will be built. Patch is compile-tested.

Signed-off-by: Nishanth Aravamudan <nacc@us.ibm.com>

--- 2.6.11-rc3-kj-v/drivers/usb/core/message.c	2005-02-03 16:57:40.000000000 -0800
+++ 2.6.11-rc3-kj/drivers/usb/core/message.c	2005-02-08 16:07:32.000000000 -0800
@@ -98,7 +98,7 @@ int usb_internal_control_msg(struct usb_
 	usb_fill_control_urb(urb, usb_dev, pipe, (unsigned char *)cmd, data,
 			     len, usb_api_blocking_completion, NULL);
 
-	retv = usb_start_wait_urb(urb, timeout, &length);
+	retv = usb_start_wait_urb(urb, msecs_to_jiffies(timeout), &length);
 	if (retv < 0)
 		return retv;
 	else
@@ -115,7 +115,7 @@ int usb_internal_control_msg(struct usb_
  *	@index: USB message index value
  *	@data: pointer to the data to send
  *	@size: length in bytes of the data to send
  *	@timeout: time in jiffies to wait for the message to complete before
  *		timing out (if 0 the wait is forever)
  *	Context: !in_interrupt ()
  *
@@ -163,7 +163,7 @@ int usb_control_msg(struct usb_device *d
  *	@data: pointer to the data to send
  *	@len: length in bytes of the data to send
  *	@actual_length: pointer to a location to put the actual length transferred in bytes
  *	@timeout: time in jiffies to wait for the message to complete before
  *		timing out (if 0 the wait is forever)
  *	Context: !in_interrupt ()
  *
@@ -196,7 +196,7 @@ int usb_bulk_msg(struct usb_device *usb_
 	usb_fill_bulk_urb(urb, usb_dev, pipe, data, len,
 			  usb_api_blocking_completion, NULL);
 
-	return usb_start_wait_urb(urb,timeout,actual_length);
+	return usb_start_wait_urb(urb,msecs_to_jiffies(timeout),actual_length);
 }
 
 /*-------------------------------------------------------------------*/

^ permalink raw reply	[flat|nested] 6+ messages in thread

end of thread, other threads:[~2005-05-19  6:25 UTC | newest]

Thread overview: 6+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
@@ -115,7 +115,7 @@ int usb_internal_control_msg(struct usb_
  *	@data: pointer to the data to send
  *	@size: length in bytes of the data to send
- *	@timeout: time in jiffies to wait for the message to complete before
+ *	@timeout: time in msecs to wait for the message to complete before
  *		timing out (if 0 the wait is forever)
  *	Context: !in_interrupt ()
@@ -163,7 +163,7 @@ int usb_control_msg(struct usb_device *d
  *	@len: length in bytes of the data to send
  *	@actual_length: pointer to a location to put the actual length transferred in bytes
- *	@timeout: time in jiffies to wait for the message to complete before
+ *	@timeout: time in msecs to wait for the message to complete before
  *		timing out (if 0 the wait is forever)
  *	Context: !in_interrupt ()
2005-02-09  0:12 [PATCH 1/63] usb/message: make usb_{control,bulk}_msg() use msecs Nishanth Aravamudan
2005-05-19  6:25 ` Nishanth Aravamudan
2005-02-15 22:29 ` [linux-usb-devel] " Greg KH
2005-05-19  6:25   ` [linux-usb-devel] [PATCH 1/63] usb/message: make Greg KH
2005-02-15 23:10   ` [linux-usb-devel] [PATCH 1/63] usb/message: make usb_{control,bulk}_msg() use msecs Nishanth Aravamudan
2005-05-19  6:25     ` [linux-usb-devel] [PATCH 1/63] usb/message: make Nishanth Aravamudan

This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.